@@ -80,7 +80,6 @@ use std::error::Error;
 
 use crate::square::{File, Rank, Square};
 use crate::color::{ByColor, Color};
-use crate::color::Color::{Black, White};
 use crate::types::{Piece, CastlingMode, RemainingChecks};
 use crate::material::Material;
 use crate::bitboard::Bitboard;
@@ -118,10 +117,10 @@ impl FenOpts {
     fn castling_fen(&self, board: &Board, castling_rights: Bitboard) -> String {
         let mut fen = String::with_capacity(4);
 
-        for color in &[White, Black] {
-            let king = board.king_of(*color);
+        for color in Color::ALL {
+            let king = board.king_of(color);
 
-            let candidates = board.by_piece(color.rook()) & Bitboard::relative_rank(*color, Rank::First);
+            let candidates = board.by_piece(color.rook()) & Bitboard::relative_rank(color, Rank::First);
 
             for rook in (candidates & castling_rights).into_iter().rev() {
                 if !self.shredder && Some(rook) == candidates.first() && king.map_or(false, |k| rook < k) {
@@ -209,9 +208,9 @@ pub enum ParseFenError {
     InvalidFullmoves,
 }
 
-impl ParseFenError {
-    fn desc(&self) -> &str {
-        match *self {
+impl fmt::Display for ParseFenError {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.write_str(match *self {
             ParseFenError::InvalidFen => "invalid fen",
             ParseFenError::InvalidBoard => "invalid board part in fen",
             ParseFenError::InvalidPocket => "invalid pocket in fen",
@@ -221,21 +220,11 @@ impl ParseFenError {
             ParseFenError::InvalidRemainingChecks => "invalid remaining checks in fen",
             ParseFenError::InvalidHalfmoveClock => "invalid halfmove clock in fen",
             ParseFenError::InvalidFullmoves => "invalid fullmove part in fen",
-        }
+        })
     }
 }
 
-impl fmt::Display for ParseFenError {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        self.desc().fmt(f)
-    }
-}
-
-impl Error for ParseFenError {
-    fn description(&self) -> &str {
-        self.desc()
-    }
-}
+impl Error for ParseFenError {}
 
 fn parse_board_fen(board_fen: &[u8]) -> Result<(Board, Bitboard), ParseFenError> {
     let mut promoted = Bitboard(0);
@@ -314,10 +303,10 @@ impl Board {
     pub fn board_fen(&self, promoted: Bitboard) -> String {
         let mut fen = String::with_capacity(15);
 
-        for rank in (0..8).map(Rank::new).rev() {
+        for rank in IntoIterator::into_iter(Rank::ALL).rev() {
             let mut empty = 0;
 
-            for file in (0..8).map(File::new) {
+            for file in File::ALL {
                 let square = Square::from_coords(file, rank);
 
                 empty = self.piece_at(square).map_or_else(|| empty + 1, |piece| {
@@ -355,7 +344,7 @@ impl FromStr for Board {
 
 impl fmt::Display for Board {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self.board_fen(Bitboard(0)))
+        f.write_str(&self.board_fen(Bitboard(0)))
     }
 }
 
@@ -391,7 +380,7 @@ impl Default for Fen {
             board: Board::default(),
             promoted: Bitboard(0),
             pockets: None,
-            turn: White,
+            turn: Color::White,
             castling_rights: Bitboard::CORNERS,
             ep_square: None,
             remaining_checks: None,
@@ -472,8 +461,8 @@ impl Fen {
         }
 
         result.turn = match parts.next() {
-            Some(b"w") | None => White,
-            Some(b"b") => Black,
+            Some(b"w") | None => Color::White,
+            Some(b"b") => Color::Black,
             Some(_) => return Err(ParseFenError::InvalidTurn),
         };
 
@@ -574,7 +563,7 @@ impl FromStr for Fen {
 
 impl fmt::Display for Fen {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", FenOpts::default().fen(self))
+        f.write_str(&FenOpts::default().fen(self))
     }
 }
 
@@ -616,7 +605,7 @@ mod tests {
     #[test]
     fn test_pockets() {
         let fen: Fen = "8/8/8/8/8/8/8/8[Q]".parse().expect("valid fen");
-        assert_eq!(fen.pockets().map_or(0, |p| p.by_piece(White.queen())), 1);
+        assert_eq!(fen.pockets().map_or(0, |p| p.by_piece(Color::White.queen())), 1);
     }
 
     #[test]
