@@ -70,7 +70,7 @@
 //! * `step`: Implements [`std::iter::Step`] for `Square`, `File`, and `Rank`.
 //!   Requires nightly.
 
-#![doc(html_root_url = "https://docs.rs/shakmaty/0.20.0")]
+#![doc(html_root_url = "https://docs.rs/shakmaty/0.20.1")]
 
 #![forbid(unsafe_op_in_unsafe_fn)]
 #![warn(missing_debug_implementations)]
@@ -102,7 +102,7 @@ pub mod zobrist;
 pub mod variant;
 
 pub use crate::square::{ParseSquareError, File, Rank, Square};
-pub use crate::color::{Color, ByColor};
+pub use crate::color::{ParseColorError, Color, ByColor, ByColorIter};
 pub use crate::types::{CastlingSide, CastlingMode, Move, Piece, Role, RemainingChecks};
 pub use crate::material::{Material, MaterialSide, ParseMaterialError};
 pub use crate::bitboard::Bitboard;
