@@ -84,15 +84,11 @@ pub struct ParseSanError;
 
 impl fmt::Display for ParseSanError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        "invalid san".fmt(f)
+        f.write_str("invalid san")
     }
 }
 
-impl Error for ParseSanError {
-    fn description(&self) -> &str {
-        "invalid san"
-    }
-}
+impl Error for ParseSanError {}
 
 /// `IllegalSan` or `AmbiguousSan`.
 #[derive(Clone, Debug, Eq, PartialEq)]
@@ -103,26 +99,16 @@ pub enum SanError {
     AmbiguousSan,
 }
 
-impl SanError {
-    fn desc(&self) -> &str {
-        match *self {
-            SanError::IllegalSan => "illegal san",
-            SanError::AmbiguousSan => "ambiguous san",
-        }
-    }
-}
-
 impl fmt::Display for SanError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        self.desc().fmt(f)
+        f.write_str(match *self {
+            SanError::IllegalSan => "illegal san",
+            SanError::AmbiguousSan => "ambiguous san",
+        })
     }
 }
 
-impl Error for SanError {
-    fn description(&self) -> &str {
-        self.desc()
-    }
-}
+impl Error for SanError {}
 
 /// A move in Standard Algebraic Notation.
 #[derive(Debug, PartialEq, Eq, Clone, Hash)]
