@@ -17,7 +17,7 @@
 use std::cmp::max;
 use std::convert::TryInto;
 use std::num::TryFromIntError;
-use std::fmt;
+use std::fmt::{self, Write as _};
 use std::str;
 use std::error::Error;
 use std::ops::Sub;
@@ -131,6 +131,11 @@ impl File {
         char::from(b'a' + u8::from(self))
     }
 
+    #[inline]
+    pub fn upper_char(self) -> char {
+        char::from(b'A' + u8::from(self))
+    }
+
     #[must_use]
     #[inline]
     pub fn offset(self, delta: i32) -> Option<File> {
@@ -154,6 +159,9 @@ impl File {
     pub fn flip_anti_diagonal(self) -> Rank {
         Rank::new(7 - u32::from(self))
     }
+
+    /// `A`, ..., `H`.
+    pub const ALL: [File; 8] = [File::A, File::B, File::C, File::D, File::E, File::F, File::G, File::H];
 }
 
 impl Sub for File {
@@ -167,7 +175,7 @@ impl Sub for File {
 
 impl fmt::Display for File {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self.char())
+        f.write_char(self.char())
     }
 }
 
@@ -244,6 +252,18 @@ impl Rank {
     pub fn flip_anti_diagonal(self) -> File {
         File::new(7 - u32::from(self))
     }
+
+    /// `First`, ..., `Eighth`.
+    pub const ALL: [Rank; 8] = [
+        Rank::First,
+        Rank::Second,
+        Rank::Third,
+        Rank::Fourth,
+        Rank::Fifth,
+        Rank::Sixth,
+        Rank::Seventh,
+        Rank::Eighth,
+    ];
 }
 
 impl Sub for Rank {
@@ -257,7 +277,7 @@ impl Sub for Rank {
 
 impl fmt::Display for Rank {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self.char())
+        f.write_char(self.char())
     }
 }
 
@@ -271,15 +291,11 @@ pub struct ParseSquareError;
 
 impl fmt::Display for ParseSquareError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        "invalid square name".fmt(f)
+        f.write_str("invalid square name")
     }
 }
 
-impl Error for ParseSquareError {
-    fn description(&self) -> &str {
-        "invalid square name"
-    }
-}
+impl Error for ParseSquareError {}
 
 /// A square index.
 #[allow(missing_docs)]
@@ -583,6 +599,23 @@ impl Square {
     }
 }
 
+mod all_squares {
+    use super::Square::{self, *};
+    impl Square {
+        /// `A1`, `B1`, ..., `G8`, `H8`.
+        pub const ALL: [Square; 64] = [
+            A1, B1, C1, D1, E1, F1, G1, H1,
+            A2, B2, C2, D2, E2, F2, G2, H2,
+            A3, B3, C3, D3, E3, F3, G3, H3,
+            A4, B4, C4, D4, E4, F4, G4, H4,
+            A5, B5, C5, D5, E5, F5, G5, H5,
+            A6, B6, C6, D6, E6, F6, G6, H6,
+            A7, B7, C7, D7, E7, F7, G7, H7,
+            A8, B8, C8, D8, E8, F8, G8, H8,
+        ];
+    }
+}
+
 from_repr_u8_impl! { Square, u8 i8 u16 i16 u32 i32 u64 i64 usize isize }
 try_from_int_impl! { Square, 0, 64, u8 i8 u16 i16 u32 i32 u64 i64 usize isize }
 unsafe_step_impl! { Square }
@@ -613,13 +646,15 @@ impl str::FromStr for Square {
 
 impl fmt::Display for Square {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}{}", self.file().char(), self.rank().char())
+        f.write_char(self.file().char())?;
+        f.write_char(self.rank().char())
     }
 }
 
 impl fmt::Debug for Square {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self.to_string().to_uppercase())
+        f.write_char(self.file().upper_char())?;
+        f.write_char(self.rank().char())
     }
 }
 
