@@ -14,7 +14,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-use std::fmt;
+use std::fmt::{self, Write as _};
 use std::char;
 use std::num;
 
@@ -124,6 +124,9 @@ impl Role {
             Role::King => 'K',
         }
     }
+
+    /// `Pawn`, `Knight`, `Bishop`, `Rook`, `Queen`, and `King`, in this order.
+    pub const ALL: [Role; 6] = [Pawn, Knight, Bishop, Rook, Queen, King];
 }
 
 macro_rules! int_from_role_impl {
@@ -181,8 +184,6 @@ macro_rules! try_role_from_int_impl {
 
 try_role_from_int_impl! { u8 i8 u16 i16 u32 i32 u64 i64 usize isize }
 
-pub const ROLES: [Role; 6] = [Pawn, Knight, Bishop, Rook, Queen, King];
-
 /// A piece with [`Color`] and [`Role`].
 #[allow(missing_docs)]
 #[derive(Copy, Clone, Eq, PartialEq, Debug, Hash)]
@@ -304,7 +305,7 @@ impl fmt::Display for Move {
         match *self {
             Move::Normal { role, from, capture, to, promotion } => {
                 if role != Role::Pawn {
-                    write!(f, "{}", role.upper_char())?;
+                    f.write_char(role.upper_char())?;
                 }
 
                 write!(f, "{}{}{}", from, if capture.is_some() { 'x' } else { '-' }, to)?;
@@ -319,15 +320,15 @@ impl fmt::Display for Move {
                 write!(f, "{}x{}", from, to)
             },
             Move::Castle { king, rook } => {
-                if king < rook {
-                    write!(f, "O-O")
+                f.write_str(if king < rook {
+                    "O-O"
                 } else {
-                    write!(f, "O-O-O")
-                }
+                    "O-O-O"
+                })
             },
             Move::Put { role, to } => {
                 if role != Role::Pawn {
-                    write!(f, "{}", role.upper_char())?;
+                    f.write_char(role.upper_char())?;
                 }
                 write!(f, "@{}", to)
             },
@@ -383,6 +384,9 @@ impl CastlingSide {
     pub fn rook_to(self, color: Color) -> Square {
         Square::from_coords(self.rook_to_file(), color.backrank())
     }
+
+    /// `KingSide` and `QueenSide`, in this order.
+    pub const ALL: [CastlingSide; 2] = [CastlingSide::KingSide, CastlingSide::QueenSide];
 }
 
 /// `Standard` or `Chess960`.
