@@ -1,3 +1,19 @@
+// This file is part of the shakmaty library.
+// Copyright (C) 2017-2021 Niklas Fiekas <niklas.fiekas@backscattering.de>
+//
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see <http://www.gnu.org/licenses/>.
+
 //! Zobrist hashing for positions.
 //!
 //! # Stability
@@ -23,7 +39,6 @@ use crate::{
     Chess,
     File,
 };
-use crate::types::ROLES;
 use std::cell::Cell;
 use std::ops::BitXorAssign;
 use std::num::NonZeroU32;
@@ -94,7 +109,13 @@ zobrist_value_impl! { u8 u16 u32 u64 u128 }
 
 /// Supports Zobrist hashing.
 pub trait ZobristHash {
-    /// Computes the Zobrist hash from scratch.
+    /// Computes the Zobrist hash of the position from scratch. Hash includes
+    /// the position, except halfmove clock and fullmove number.
+    ///
+    /// Warning: Zobrist hashes have good collision resistance, but can be
+    /// forged efficiently. In this implementation, impossible positions with
+    /// more than 3 remaining checks in Three-check and more than standard
+    /// material in Crazyhouse pockets are particularly prone to collisions.
     fn zobrist_hash<V: ZobristValue>(&self) -> V;
 
     /// Prepares an incremental update of the Zobrist hash before playing move
@@ -195,6 +216,10 @@ impl<P, V: ZobristValue> Zobrist<P, V> {
     pub fn into_inner(self) -> P {
         self.pos
     }
+
+    pub fn as_inner(&self) -> &P {
+        &self.pos
+    }
 }
 
 impl<P: ZobristHash, V: ZobristValue> Zobrist<P, V> {
@@ -276,9 +301,9 @@ fn hash_position<P: Position, V: ZobristValue>(pos: &P) -> V {
     }
 
     if let Some(pockets) = pos.pockets() {
-        for color in [Color::White, Color::Black] {
-            for role in ROLES {
-                zobrist ^= V::zobrist_for_pocket(color, role, pockets.by_piece(role.of(color)));
+        for (color, pocket) in pockets.as_ref().zip_color() {
+            for role in Role::ALL {
+                zobrist ^= V::zobrist_for_pocket(color, role, pocket.by_role(role));
             }
         }
     }
@@ -288,8 +313,8 @@ fn hash_position<P: Position, V: ZobristValue>(pos: &P) -> V {
     }
 
     let castles = pos.castles();
-    for color in [Color::White, Color::Black] {
-        for side in [CastlingSide::KingSide, CastlingSide::QueenSide] {
+    for color in Color::ALL {
+        for side in CastlingSide::ALL {
             if castles.has(color, side) {
                 zobrist ^= V::zobrist_for_castling_right(color, side);
             }
@@ -301,8 +326,8 @@ fn hash_position<P: Position, V: ZobristValue>(pos: &P) -> V {
     }
 
     if let Some(remaining_checks) = pos.remaining_checks() {
-        for color in [Color::White, Color::Black] {
-            zobrist ^= V::zobrist_for_remaining_checks(color, *remaining_checks.by_color(color));
+        for (color, remaining) in remaining_checks.as_ref().zip_color() {
+            zobrist ^= V::zobrist_for_remaining_checks(color, *remaining);
         }
     }
 
@@ -373,10 +398,23 @@ mod tests {
         }
     }
 
+    #[cfg(feature = "variant")]
+    #[test]
+    fn test_variants_not_distinguished() {
+        // Useful when indexing a table of opening names by Zorbist hash.
+        let chess: u128 = Chess::default().zobrist_hash();
+        let crazyhouse = crate::variant::Crazyhouse::default().zobrist_hash();
+        let three_check = crate::variant::ThreeCheck::default().zobrist_hash();
+        let king_of_the_hill = crate::variant::KingOfTheHill::default().zobrist_hash();
+        assert_eq!(chess, crazyhouse);
+        assert_eq!(chess, three_check);
+        assert_eq!(chess, king_of_the_hill);
+    }
+
     #[test]
     fn test_full_pockets() {
         // 8/8/8/7k/8/8/3K4/8[ppppppppppppppppnnnnbbbbrrrrqq] w - - 0 54
-        for color in [Color::Black, Color::White] {
+        for color in Color::ALL {
             assert_ne!(
                 u64::zobrist_for_pocket(color, Role::Pawn, 16),
                 u64::zobrist_for_pocket(color, Role::Pawn, 15)
